@@ -35,13 +35,13 @@ setMethodS3("extractRawGenomicSignals", "AromaUnitTotalCnBinaryFileList", functi
   if (dropEmpty) {
     verbose && enter(verbose, "Dropping empty data sets");
     ns <- sapply(cnList, FUN=nbrOfLoci);
-    keep <- whichVector(ns > 0);
+    keep <- which(ns > 0);
     cnList <- cnList[keep];
     ns <- sapply(cnList, FUN=nbrOfLoci);
     nbrOfSources <- length(cnList);
     verbose && exit(verbose);
   } else {
-    keep <- seq(along=cnList);
+    keep <- seq_along(cnList);
   }
   attr(cnList, "included") <- keep;
 
@@ -143,7 +143,7 @@ setMethodS3("extractMergedRawCopyNumbers", "AromaUnitTotalCnBinaryFileList", fun
     verbose && exit(verbose);
 
     verbose && enter(verbose, "Removing shifts");
-    for (kk in seq(along=cnList)) {
+    for (kk in seq_along(cnList)) {
       # Unshift full resolution data
       cn <- cnList[[kk]];
       cn$y <- cn$y - deltas[kk];
@@ -188,7 +188,7 @@ setMethodS3("extractMergedRawCopyNumbers", "AromaUnitTotalCnBinaryFileList", fun
   verbose && exit(verbose);
 
   verbose && enter(verbose, "Assign platform specific weights");
-  for (kk in seq(along=cnList)) {
+  for (kk in seq_along(cnList)) {
     cn <- cnList[[kk]];
     cn$weights <- rep(ws[kk], times=nbrOfLoci(cn));
     cnList[[kk]] <- cn;
